@@ -12,7 +12,7 @@ def get_start_end(start, end, table_name, dbstream: DBStream):
         schema_name = table_name.split(".")[0]
         table_name = table_name.split(".")[1]
         max_date = dbstream.get_max(schema=schema_name, table=table_name, field="date", filter_clause="")
-        if not start:
+        if not max_date:
             start = str(datetime.datetime.strptime(end, "%Y-%m-%d") + datetime.timedelta(days=-10))[:10]
         else:
             if isinstance(max_date, str):
